OC.L10N.register(
    "settings",
    {
    "{actor} added you to group {group}" : "{actor} aldonis vin al grupo {group}",
    "You added {user} to group {group}" : "Vi aldonis uzanton {user} al grupo {group}",
    "{actor} added {user} to group {group}" : "{actor} aldonis uzanton {user} al grupo {group}",
    "An administrator added you to group {group}" : "Administranto aldonis vin al grupo {group}",
    "An administrator added {user} to group {group}" : "Administranto aldonis uzanton {user} al grupo {group}",
    "{actor} removed you from group {group}" : "{actor} forigis vin el grupo {group}",
    "You removed {user} from group {group}" : "Vi forigis uzanton {user} el grupo {group}",
    "{actor} removed {user} from group {group}" : "{actor} forigi uzanton {user} el grupo {group}",
    "An administrator removed you from group {group}" : "Administranto forigis vin el grupo {group}",
    "An administrator removed {user} from group {group}" : "Administranto forigis uzanton {user} el grupo {group}",
    "Your <strong>group memberships</strong> were modified" : "Viaj <strong>grupaj membrecoj</strong> modifiĝis",
    "{actor} changed your password" : "{actor} ŝanĝis vian pasvorton",
    "You changed your password" : "Vi ŝanĝis vian pasvorton",
    "Your password was reset by an administrator" : "Vian pasvorton restarigis administranton",
    "{actor} changed your email address" : "{actor} ŝanĝis vian retpoŝtadreson",
    "You changed your email address" : "Vi ŝanĝis vian retpoŝtadreson",
    "Your email address was changed by an administrator" : "Administranto ŝanĝis vian retpoŝtadreson",
    "You deleted app password \"{token}\"" : "Vi forigis aplikaĵan pasvorton „{token}“",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Vi alinomis aplikaĵan pasvorton „{token}“ al „{newToken}“",
    "You granted filesystem access to app password \"{token}\"" : "Vi permesis aliron al dosiersistemo al aplikaĵa pasvorton „{token}“",
    "You revoked filesystem access from app password \"{token}\"" : "Vi senvalidigis aliron al dosiersistemo el aplikaĵa pasvorton „{token}“",
    "Security" : "Sekurigo",
    "You successfully logged in using two-factor authentication (%1$s)" : "Vi sukcese ensalutis uzante dufazan aŭtentigon (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Ensaluta provo uzante dufazan aŭtentigo malsukcesis (%1$s)",
    "Remote wipe was started on %1$s" : "Defora forviŝado komenciĝis ĉe %1$s",
    "Remote wipe has finished on %1$s" : "Defora forviŝado finis ĉe %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Via <strong>pasvorto</strong> aŭ <strong>retpoŝtadreso</strong> estis modifita",
    "Settings" : "Agordoj",
    "Wrong password" : "Neĝusta pasvorto",
    "Saved" : "Konservita",
    "Unable to change password" : "Ne eblis ŝanĝi la pasvorton",
    "Authentication error" : "Aŭtentiga eraro",
    "Wrong admin recovery password. Please check the password and try again." : "Neĝusta reekhava pasvorto de administranto. Bv. kontroli la pasvorton kaj reprovi.",
    "Administrator documentation" : "Dokumentaro por administranto",
    "User documentation" : "Dokumentaro por uzanto",
    "Invalid SMTP password." : "Nevalida SMTP-pasvorto.",
    "Email setting test" : "Provo de retpoŝtagordo",
    "Well done, %s!" : "Bonege, %s!",
    "If you received this email, the email configuration seems to be correct." : "Se vi ricevis tiun ĉi retmesaĝon, retpoŝta agordo estas ĝusta, espereble.",
    "Email could not be sent. Check your mail server log" : "Retmesaĝo ne eblis esti sendita. Kontrolu vian servil-protokolon.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Problem dum sendado de la retmesaĝo. Bv. ekzameni viajn agordojn. (Eraro: %s)",
    "Invalid mail address" : "Nevalida retpoŝtadreso",
    "Settings saved" : "Agordoj konservitaj",
    "Unable to change full name" : "Ne eblis ŝanĝi la plenan nomon",
    "Unable to change email address" : "Ne eblis ŝanĝi retpoŝtadreson",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Por kontroli vian Twitter-konton, bv. afiŝi la jenan pepaĵon („tweet“) (certigu afiŝi ĝin sen iu linisalto):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Por kontroli vian retejon, metu la jenan enhavon en la radikon de via retejo en „.well-known/CloudIdVerificationCode.txt“ (certigu, ke la tuta teksto estas unulinia):",
    "%1$s changed your password on %2$s." : "%1$s ŝanĝis vian pasvorton ĉe %2$s.",
    "Your password on %s was changed." : "Via pasvorto ĉe %s estis ŝanĝita.",
    "Your password on %s was reset by an administrator." : "Via pasvorto ĉe %s estis restartigita de administranto.",
    "Password for %1$s changed on %2$s" : "Pasvorto por %1$s ŝanĝita ĉe %2$s",
    "Password changed for %s" : "Pasvorto ŝanĝita por %s",
    "If you did not request this, please contact an administrator." : "Se vi mem ne petis tion, bv. kontakti vian administranton.",
    "Your email address on %s was changed." : "Via retpoŝtadreso ĉe %s estis ŝanĝita.",
    "Your email address on %s was changed by an administrator." : "Via retpoŝtadreso ĉe %s estis ŝanĝita de administranto.",
    "Email address for %1$s changed on %2$s" : "Retpoŝtadreso de %1$s estis ŝanĝita. ĉe %2$s",
    "Email address changed for %s" : "Retpoŝtadreso ŝanĝita por %s",
    "The new email address is %s" : "La nova retpoŝtadreso estas %s",
    "Your %s account was created" : "Via konto %s kreiĝis",
    "Welcome aboard" : "Bonvenon",
    "Welcome aboard %s" : "Bonvenon %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bonvenon ĉe via konto %s; vi povas aldoni, protekti kaj kunhavigi viajn datumojn.",
    "Set your password" : "Agordi vian pasvorton",
    "Go to %s" : "Iri al %s",
    "Install Client" : "Instali kienton",
    "Apps" : "Aplikaĵoj",
    "Personal" : "Persona",
    "Administration" : "Administrado",
    "Users" : "Uzantoj",
    "Additional settings" : "Plia agordo",
    "Groupware" : "Grupa kunlaborado",
    "Overview" : "Superrigardo",
    "Basic settings" : "Bazaj agordoj",
    "Sharing" : "Kunhavigo",
    "Calendar" : "Kalendaro",
    "Personal info" : "Persona informo",
    "Mobile & desktop" : "Porteblaj kaj labortablaj aplikaĵoj",
    "Email server" : "Retpoŝtoservilo",
    "Background jobs" : "Fonaj taskoj",
    "Unlimited" : "Senlima",
    "Verifying" : "Kontrolado",
    "Verifying …" : "Kontrolado...",
    "Verify" : "Kontroli",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankas kelkaj malnepraj kolumnoj en la datumbazo. Pro la ebla malrapideco aldoni kolumnojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-columns“, dum la servilo estas funkcianta. Kiam la kolumnoj aldoniĝos, la uzo de tiuj tabelojn estos kutime pli rapida.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Mankas kelkaj ĉefŝlosiloj en la datumbazo. Pro la ebla malrapideco aldoni ĉefŝlosilojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-primary-keys“, dum la servilo estas funkcianta.",
    "Disabled" : "Malkapabligita",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La PHP-funkcio „set_time_limit“ (angle „difini tempolimo“) ne disponeblas. Pro tio, skriptoj povus halti mezvoje, eble difektante vian instalaĵon. Ebligi tiun funkcion estas tre rekomendita.",
    "Supported" : "Subtenite",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Via PHP ne subtenas la bibliotekon FreeType, kio provokos misfunkcion de profilbildo kaj de la agorda fasado.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ŝajnas ne esti taŭge agordita por informpeti sistemajn medivariablojn. La testado kun getenv(\"PATH\") revenigas nur malplenan respondon.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La nurlega agordodosiero estis ebligita. Tio baras modifon de kelkaj agordoj per la reta fasado. Plie, la dosiero bezonos esti markita mane kiel legebla dum ĉiu ĝisdatigo.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Via datumbazo ne uzas la nivelon de izoltransakcio „READ COMMITTED“ (angle por „asertita datumlegado“). Tio povas estigi problemojn, kiam pluraj agoj ruliĝas paralele.",
    "Nextcloud settings" : "Nextcloud-agordoj",
    "Enable" : "Ŝalti",
    "None" : "Nenio",
    "Allow apps to use the Share API" : "Ebligi aplikaĵojn uzi la API-on pri kunhavigo",
    "Allow resharing" : "Permesi rekunhavigon",
    "Allow sharing with groups" : "Permesi kunhavigon kun grupoj",
    "Restrict users to only share with users in their groups" : "Limigi uzantojn al kunhavigado kun uzantoj en iiajn grupojn",
    "Allow public uploads" : "Permesi publikajn alŝutojn",
    "Always ask for a password" : "Ĉiam peti pasvorton",
    "Enforce password protection" : "Devigi pasvortan protekton ",
    "Enforce expiration date" : "Devigi limdaton",
    "This text will be shown on the public link upload page when the file list is hidden." : "Tiu ĉi teksto montriĝos en la publika paĝo de alŝutado, kiam la dosierlisto estas kaŝita.",
    "Default share permissions" : "Defaŭltaj kunhavigaj permesoj",
    "Two-Factor Authentication" : "Dufaza aŭtentigo",
    "Enforce two-factor authentication" : "Devigi dufazan aŭtentigon",
    "Limit to groups" : "Limigi al grupoj",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Devigo de dufaza aŭtentigo povas ekzisti nur por certaj grupoj.",
    "Enforced groups" : "Devigataj grupoj",
    "Excluded groups" : "Nedevigataj grupoj",
    "Save changes" : "Konservi modifojn",
    "Update to {update}" : "Ĝisdatigi al {update}",
    "Remove" : "Forigi",
    "Featured" : "Elstaraj",
    "This app is supported via your current Nextcloud subscription." : "Tiu aplikaĵo estas subtenita per via nuna Nextcloud-abono.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Elstaraj aplikaĵoj estas programataj de kaj ene de la komunumo. Ili alportas kernajn trajtojn kaj ili povas tuj uziĝi.",
    "Learn more" : "Scii pli",
    "Disable all" : "Malŝalti ĉiujn",
    "Icon" : "Piktogramo",
    "Name" : "Nomo",
    "Version" : "Versio",
    "Level" : "Nivelo",
    "Actions" : "Agoj",
    "Results from other categories" : "Rezultoj el aliaj kategorioj",
    "No apps found for your version" : "Neniu aplikaĵo trovita por via versio",
    "Groups" : "Grupoj",
    "Group name" : "Gruponomo",
    "Loading" : "Ŝargado",
    "Type" : "Tipo",
    "Confirm" : "Konfirmi",
    "Cancel" : "Nuligi",
    "Description" : "Priskribo",
    "View in store" : "Vidi en la aplikaĵejo",
    "Visit website" : "Viziti retejon",
    "Admin documentation" : "Dokumentaro por administranto",
    "Developer documentation" : "Dokumentaro por programisto",
    "Details" : "Detaloj",
    "All" : "Ĉiuj",
    "Limit app usage to groups" : "Limigi aplikaĵan uzon al grupoj",
    "Update to {version}" : "Ĝisdatigi al {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Tiu aplikaĵo ne instaliĝas, ĉar la jenaj dependecoj ne plenumiĝas:",
    "Categories" : "Kategorioj",
    "Resources" : "Rimedoj",
    "Documentation" : "Dokumentaro",
    "Report a bug" : "Raporti problemon",
    "Request feature" : "Peti novan funkcion",
    "Ask questions or discuss" : "Demandi aŭ priparoli",
    "Rate" : "Pritakso",
    "Changelog" : "Ŝanĝoprotokolo",
    "Google Chrome for Android" : "Google Chrome por Android",
    "{productName} Android app" : "Android-aplikaĵo {productName}",
    "This session" : "Tiu ĉi seanco",
    "Marked for remote wipe" : "Elektita por fora forviŝado",
    "Device settings" : "Aparataj agordoj",
    "Allow filesystem access" : "Permesi aliron al dosiersistemo",
    "Rename" : "Alinomi",
    "Revoke" : "Senvalidigi",
    "Wipe device" : "Forviŝi aparaton",
    "Device" : "Aparato",
    "Last activity" : "Lasta aktivaĵo",
    "Devices & sessions" : "Aparatoj kaj seancoj",
    "Web, desktop and mobile clients currently logged in to your account." : "Reta, surtabla kaj portebla klientoj nun konektitaj al via konto.",
    "Error while creating device token" : "Eraro dum kreo de aparata ĵetono",
    "App name" : "Aplijaĵa nomo",
    "Create new app password" : "Krei novan aplikaĵan pasvorton",
    "Could not copy app password. Please copy it manually." : "Ne eblis kopii la aplikaĵan pasvorton. Bv. kopii ĝin permane.",
    "Login" : "Ensaluti",
    "Password" : "Pasvorto",
    "Show QR code for mobile apps" : "Montri rapidrespondan (QR) kodon por porteblaj aplikaĵoj",
    "Use system cron service to call the cron.php file every 5 minutes." : "Uzu la sisteman „cron“-servon por voki cron.php ĉiujn 5 minutojn.",
    "Password confirmation is required" : "Konfirmo per pasvorto estas bezonata",
    "Server-side encryption" : "Ĉeservila ĉifrado",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Ĉeservila ĉifrado elbigas ĉifri ĉiujn alŝutitajn dosierojn al la servilo. Tio havas kelkajn limigojn kiel pli malbonan rendimenton, do ŝaltu tion nur se necese.",
    "Enable server-side encryption" : "Ŝalti ĉeservilan ĉifradon",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Neniu ĉifrado-modulo ŝargita. Bv. ebligi iun ĉifrado-modulon en la aplikaĵa menuo.",
    "Select default encryption module:" : "Elekti defaŭltan ĉifrado-modulon:",
    "Enable encryption" : "Ŝalti ĉifradon",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Kiam ĉeservila ĉifrado estas ŝaltita, ĉiuj dosieroj alŝutitaj al la servilo ekde nun estos ĉifritaj ĉe la servilo. Malebligi ĉifradon povos esti farite poste nur se la uzata ĉifrado-modulo subtenas tion kaj ĉiuj kondiĉoj (ekz. difini restaŭran ŝlisilon) estos kunigitaj.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Ĉifrado sola ne garantias sekurigon de la sistemo. Bv. vidi la dokumentaron por pli da informoj pri kiel funkcias la ĉifrado kaj pri subtenata scenaro.",
    "Be aware that encryption always increases the file size." : "Atentu, ke ĉifrado ĉiam pligrandigas dosierojn.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Ĉiam estas bone krei savkopiojn de viaj datumoj. Se tiuj ĉi lastaj estas ĉifritaj, certigu, ke vi savkopias ankaŭ la ĉifroŝlosilon kune kun la datumoj.",
    "This is the final warning: Do you really want to enable encryption?" : "Jen la fina averto: ĉu vi certe volas ŝalti ĉifradon?",
    "Submit" : "Sendi",
    "Current password" : "Nuna pasvorto",
    "New password" : "Nova pasvorto",
    "Picture provided by original account" : "Bildo el la origina konto",
    "You are a member of the following groups:" : "Vi estas membro el la jenaj grupoj:",
    "No email address set" : "Neniu retpoŝta adreso agordita",
    "No language set" : "Neniu lingvo agordita",
    "Languages" : "Lingvoj",
    "Help translate" : "Helpu traduki",
    "Week starts on {firstDayOfWeek}" : "Semajno komencas je {firstDayOfWeek}",
    "Your phone number" : "Via telefonnumero",
    "Timezone" : "Horzono",
    "Change" : "Ŝanĝi",
    "Delete" : "Forigi",
    "Default language" : "Defaŭlta lingvo",
    "Common languages" : "Ordinaraj lingvoj",
    "Password change is disabled because the master key is disabled" : "Pasvorta ŝanĝo ne eblas, ĉar la ĉefa ŝlosilo estas neebligita",
    "Display name" : "Vidiga nomo",
    "Email" : "Retpoŝtadreso",
    "Quota" : "Kvoto",
    "Language" : "Lingvo",
    "Avatar" : "Avataro",
    "Group admin for" : "Grupadministranto por",
    "Storage location" : "Konserveja loko",
    "Last login" : "Lasta ensaluto",
    "{size} used" : "{size} uzataj",
    "Delete account" : "Forigi konton",
    "Resend welcome email" : "Resendi bonvenan retpoŝtmesaĝon",
    "Remote wipe of devices" : "Defora forviŝado de aparatoj",
    "Wipe {userid}'s devices" : "Forviŝi la aparatojn de {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Forigi la tuton de la konto de {userid}, inkluzive de ĉiuj ties personaj dosieroj, datumoj el aplikaĵoj, k.t.p.",
    "Account deletion" : "Forigo de konto",
    "Delete {userid}'s account" : "Forigi konton de {userid}",
    "Welcome mail sent!" : "Bonvena retpoŝtmesaĝo sendita!",
    "Done" : "Farita",
    "Edit" : "Modifi",
    "Show storage path" : "Montri vojon al konservejo",
    "Show last login" : "Montri lastan ensaluton",
    "Send email" : "Sendi retpoŝtmesaĝon",
    "Default quota" : "Defaŭlta kvoto",
    "Select default quota" : "Elekti defaŭltan kvoton",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Gravas agordi tiun ĉi servilon por povi sendi retpoŝtmesaĝojn, ekz. por restarigo de pasvorto aŭ sciigoj.",
    "Send mode" : "Kiel sendi",
    "Encryption" : "Ĉifrado",
    "Sendmail mode" : "Sendmail-reĝimo",
    "Disable certificate verification (insecure)" : "Ne kontroli atestilon (nesekura)",
    "From address" : "El adreso",
    "Domain" : "Domajno",
    "Server address" : "Servila adreso",
    "Host" : "Gastigo",
    "Port" : "Pordo",
    "Authentication" : "Aŭtentigo",
    "Authentication required" : "Aŭtentiĝo nepras",
    "Saving…" : "Konservado...",
    "Save settings" : "Konservi agordojn",
    "Security & setup warnings" : "Avertoj pri sekureco kaj agordoj",
    "All checks passed." : "Ĉiuj testoj sukcese trapasitaj.",
    "There are some errors regarding your setup." : "Estas kelkaj eraroj pri via instalaĵo.",
    "There are some warnings regarding your setup." : "Estas kelkaj avertoj pri via instalaĵo.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Kiel administranto, vi povas agordi plidetale la kunhavigon. Bv. vidi la dokumentaron pri tio.",
    "Apply" : "Validigi",
    "Admins" : "Administrantoj",
    "Location" : "Loko",
    "Profile picture" : "Profila bildo",
    "About" : "Pri",
    "Full name" : "Plena nomo",
    "Phone number" : "Telefonnumero",
    "Website" : "Retejo",
    "Locale" : "Lokaĵaro",
    "Private" : "Privata",
    "Local" : "Loka",
    "Federated" : "Federated",
    "Your apps" : "Viaj aplikaĵoj",
    "Active apps" : "Aktivaj aplikaĵoj",
    "Disabled apps" : "Malŝaltitaj aplikaĵoj",
    "Updates" : "Ĝisdatigoj",
    "App bundles" : "Aplikaĵaj kuniĝoj",
    "Hide" : "Malmontri",
    "Download and enable" : "Elŝuti kaj ŝalti",
    "Disable" : "Malŝalti",
    "Unknown" : "Nekonata",
    "Never" : "Neniam",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplikaĵo estis ŝaltita, sed ĝi bezonas ĝisdatiĝi. Vi estos direktita al ĝisdatiga paĝon post 5 sekundoj.",
    "Do you really want to wipe your data from this device?" : "Ĉu vi vere volas forviŝi viajn datumojn el tiu ĉi aparato?",
    "Confirm wipe" : "Konfirmi forviŝadon",
    "Error while wiping the device with the token" : "Eraro dum forviŝado de la aparato kun la ĵetono",
    "Error while updating device token name" : "Eraro dum ĝisdatigo de la nomo de la aparataj ĵetonoj",
    "Error while updating device token scope" : "Eraro dum ĝisdatigo de la amplekso de la aparataj ĵetonoj",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Estis tro multaj petoj de via reto. Reprovu poste aŭ kontaktu vian administranton se tio estas eraro.",
    "Error" : "Eraro",
    "Forum" : "Forumo",
    "Legal notice" : "Leĝa regularo",
    "Privacy policy" : "Privateca regularo",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Programita de la {communityopen}Nextcloud-komunumo{linkclose}, la {githubopen}fontkodo{linkclose} havas {licenseopen}AGPL{linkclose}-permesilon.",
    "Like our Facebook page" : "Ŝatu nian Facebook-paĝon",
    "Follow us on Mastodon" : "Sekvu nin per Mastodon",
    "Check out our blog" : "Vizitu nian blogon",
    "Subscribe to our newsletter" : "Aboni nian retan bultenon",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tiu elkomunuma eldono de Nextcloud ne estas subtenata, kaj tuj-sciigoj ne disponeblas.",
    "Open documentation" : "Malfermi la dokumentaron",
    "Use a second factor besides your password to increase security for your account." : "Uzu duan fazon krom via pasvorto por plisekurigi vian konton.",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezbona pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Group list is empty" : "Gruplisto malpenas",
    "Unable to retrieve the group list" : "Ne eblis ricevi grupliston",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tiu aplikaĵo ne postulas minimuman Nextcloud-version. Tio estos eraro en la estonteco.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tiu aplikaĵo ne postulas maksimuman Nextcloud-version. Tio estos eraro en la estonteco.",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Okaze de perdo de aparato aŭ eliro de la organizaĵo, tio povas defore forviŝi la datumojn de Nextcloud el ĉiuj aparatoj ligitaj per {userid}. Nur funkcias, se la aparatoj estas konektitaj  al interreto.",
    "Sending…" : "Sendado...",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Tiu aplikaĵo ne kongruas kun via Nextcloud-versio. Se vi daŭrigas, vi tamen povos instali ĝin, sed eble tiu aplikaĵo ne funkcios bone.",
    "SSL" : "SSL",
    "Credentials" : "Aŭtentigiloj",
    "SMTP Password" : "SMTP-pasvorto",
    "Save" : "Konservi",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Gravas por sekureco kaj rapideco de via servilo, ke ĉio estu agordita bone. Por helpi vin pri tio, ni faras kelkajn aŭtomatajn testojn. Bv. vidi la dokumentaron por pli da informoj.",
    "Checking for system and security issues." : "Kontrolado de problemoj pri sistemo kaj sekurigo.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Bv. zorgeme kontroli la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">manlibroj pri instalaĵo ↗</a>, kaj kontroli avertojn kaj erarojn en la <a href=\"%2$s\">protokolo</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Kontrolu sekurecon de via servilo Nextcloud pere de <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nia sekureca ekzameno ↗</a>."
},
"nplurals=2; plural=(n != 1);");
